@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: acord.cpp,v 1.7 2003/01/20 17:57:17 cepek Exp $
+ *  $Id: acord.cpp,v 1.13 2003/11/06 17:58:57 cepek Exp $
  */
 
  
@@ -28,6 +28,7 @@
 #include <gamalib/local/orientation.h>
 #include <gamalib/local/median/g2d_coordinates.h>
 #include <gamalib/local/acord/approx_heights.h>
+#include <gamalib/local/acord/approx_vectors.h>
 #include <gamalib/local/acord/reduce_observations.h>
 
 #include <iomanip>
@@ -57,16 +58,36 @@ Acord::Acord(PointData& b, ObservationData& m)
       else if (hp)  given_z++,   set_z  .insert(c);
     }
 
-  OD.for_each(CountObs(observations));
+  for (ObservationData::const_iterator 
+         i=OD.begin(), e=OD.end(); i!=e; ++i, ++observations);
 
-  if (Consistent(PD, OD)) return;
+
+  if (Consistent(PD)) return;
 
   for (PointData::iterator ii=PD.begin(); ii!=PD.end(); ++ii)
     {
       LocalPoint& p = (*ii).second;
-
+      
       if (p.test_xy()) p.set_xy(p.x(), -p.y());
     }
+  
+  for (ObservationData::ClusterList::iterator 
+         ci=OD.CL.begin(), ei=OD.CL.end(); ci!=ei; ++ci)
+    {
+      ObservationData::ClusterType *cluster = *ci;
+      for (ObservationList::iterator 
+             m = cluster->observation_list.begin(),
+             e = cluster->observation_list.end()  ; m!=e; ++m)
+        {
+          Observation *obs = *m;
+          bool b = false;
+ 
+          if      (dynamic_cast<Y*>    (obs))  b = true;
+          else if (dynamic_cast<Ydiff*>(obs))  b = true;
+
+          if (b)  obs->set_value( -obs->value() );
+        }
+    } 
 }
 
 void Acord::execute()
@@ -88,10 +109,38 @@ void Acord::execute()
         ApproximateHeights ah(PD, OD);
         ah.execute();
 	
+        ApproximateVectors av(PD, OD);
+        av.execute();
+	
         {
           // all transformed slope distances go to a single standpoint
           StandPoint* standpoint = new StandPoint(&OD);
-          OD.for_each(Acord::SlopeToHorizontal(standpoint->observation_list));
+          for (ObservationData::iterator t=OD.begin(), e=OD.end(); t!=e; ++t)
+            {
+              Observation* obs = *t;
+
+              S_Distance* s = dynamic_cast<S_Distance*>(obs);
+              if (s == 0) continue;
+
+              StandPoint* c = dynamic_cast<StandPoint*>(s->ptr_cluster());
+              if (c == 0) continue;   // this should newer happen
+
+              PointID from = s->from();
+              PointID to   = s->to();
+              
+              // look for a zenith angle corresponding to the given slope distance
+              ObservationList::iterator i   = c->observation_list.begin();
+              ObservationList::iterator end = c->observation_list.end();
+              for ( ;i!=end; ++i)
+                if (Z_Angle* z = dynamic_cast<Z_Angle*>(*i))
+                  if (from == z->from() && to == z->to())
+                    {
+                      // ... and fake a horizontal distance
+                      standpoint->observation_list.push_back(new Distance(from, to, s->value()*sin(z->value())));
+                      continue;
+                    }
+
+            }
           // bind observations to the cluster
           standpoint->update();
           // insert standpoint into `observation data'
@@ -107,7 +156,10 @@ void Acord::execute()
 	RO.execute();
 	
         ObservationList local;
-        OD.for_each(Observation::CopyTo(local));
+        for (ObservationData::iterator i=OD.begin(), e=OD.end(); i!=e; ++i) 
+        {
+          local.push_back(*i);
+        }
         
         Orientation orp(PD, local);
         orp.add_all();
@@ -161,30 +213,6 @@ void Acord::execute()
     }
 }
 
-void Acord::SlopeToHorizontal::operator()(Observation* obs)
-{
-  S_Distance* s = dynamic_cast<S_Distance*>(obs);
-  if (s == 0) return;
-
-  StandPoint* c = dynamic_cast<StandPoint*>(s->ptr_cluster());
-  if (c == 0) return;   // this should newer happen
-
-  PointID from = s->from();
-  PointID to   = s->to();
-
-  // look for a zenith angle corresponding to the given slope distance
-  ObservationList::iterator i   = c->observation_list.begin();
-  ObservationList::iterator end = c->observation_list.end();
-  for ( ;i!=end; ++i)
-    if (Z_Angle* z = dynamic_cast<Z_Angle*>(*i))
-      if (from == z->from() && to == z->to())
-        {
-          // ... and fake a horizontal distance
-          OL.push_back(new Distance(from, to, s->value()*sin(z->value())));
-          return;
-        }
-
-}
 
 
 
