@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: network.cpp,v 1.3 2002/10/24 17:04:12 cepek Exp $
+ *  $Id: network.cpp,v 1.11 2004/02/02 17:07:49 cepek Exp $
  */
 
 #include <fstream>
@@ -35,12 +35,16 @@
 #include <gamalib/itstream.h>
 #include <gamalib/statan.h>
 #include <gamalib/skipcomm.h>
-#include <gamalib/version.h>
+#include <gnu_gama/version.h>
 
 using namespace std;
 using namespace GaMaLib;
 
 
+typedef GNU_gama::List<GNU_gama::Cluster<Observation>*> ClusterList;
+typedef GNU_gama::Cluster<Observation>                  Cluster;
+
+
 LocalNetwork::LocalNetwork()        
   : pocbod_(0), tst_redbod_(false), pocmer_(0), tst_redmer_(false),
     m_0_apr_(10), konf_pr_(0.95), tol_abs_(1000), typ_m_0_(empiricka_),
@@ -111,22 +115,29 @@ void LocalNetwork::revision_observations()
 {
   if (!tst_redbod_) revision_points();
 
-  OD.for_each(FilterOutUnused(PD));
+  {
+    const LocalRevision local_rev(PD);
+    for (ObservationData::iterator i=OD.begin(), e=OD.end(); i!=e; ++i)
+      {
+        Observation* m = *i;
+        if (!m->revision(&local_rev)) m->set_passive();
+      }
+  }
 
   // test cycle for StandPoint clusters with single direction
-  const ClusterList& CL = OD.CL;
-  for (ClusterList::const_iterator cit=CL.begin(); cit!=CL.end(); ++cit)
+  ClusterList& CL = OD.CL;
+  for (ClusterList::iterator cit=CL.begin(); cit!=CL.end(); ++cit)
     {
-      if (const StandPoint* sp = dynamic_cast<const StandPoint*>(*cit))
+      if (StandPoint* sp = dynamic_cast<StandPoint*>(*cit))
         {
           // 1.3.08 *** check for directions pointing to the same targer
           set<PointID> targets;
 
           int active_directions = 0;
-          for (ObservationList::const_iterator i=sp->observation_list.begin();
+          for (ObservationList::iterator i=sp->observation_list.begin();
                i != sp->observation_list.end(); ++i)
             {
-              if (Direction* d = dynamic_cast<Direction*>(*i))
+              if (const Direction* d = dynamic_cast<const Direction*>(*i))
                 if (d->active())
                   {
                     set<PointID>::const_iterator s = targets.find( d->to() );
@@ -140,7 +151,7 @@ void LocalNetwork::revision_observations()
           
           if (active_directions < 2)
             {
-              for (ObservationList::const_iterator 
+              for (ObservationList::iterator 
                      i  = sp->observation_list.begin();
                    i != sp->observation_list.end(); ++i)
                 if (Direction* d = dynamic_cast<Direction*>(*i))
@@ -150,9 +161,17 @@ void LocalNetwork::revision_observations()
       (*cit)->update();
     }
   
-  RSM.erase(RSM.begin(), RSM.end());
-  vyloucena_mer_.erase(vyloucena_mer_.begin(), vyloucena_mer_.end());
-  OD.for_each(FilterOutPassive(RSM, vyloucena_mer_));
+  // RSM.erase(RSM.begin(), RSM.end());
+  // removed_obs.erase(removed_obs.begin(), removed_obs.end());
+  RSM.clear();
+  removed_obs.clear();
+  for (ObservationData::iterator i=OD.begin(), e=OD.end(); i!=e; ++i)
+    {
+      Observation* m = *i;
+      
+      if (m->active()) RSM.push_back(m);
+      else             removed_obs.push_back(m);
+    }
   pocmer_ = RSM.size();
 
   tst_redmer_ = true;
@@ -187,8 +206,8 @@ void LocalNetwork::project_equations()
     const size_t  M = V * loclin.max_size;   // reserved memory 
 
 
-    SparseMatrix<Double, Index>* 
-      tmp = new SparseMatrix<Double, Index>(M, V, 0);
+    GNU_gama::SparseMatrix<Double, Index>* 
+      tmp = new GNU_gama::SparseMatrix<Double, Index>(M, V, 0);
 
     b.reset(pocmer_);   // initialisation of base class OLS
     rhs_.reset(pocmer_);
@@ -227,7 +246,7 @@ void LocalNetwork::project_equations()
   seznez_.resize(pocet_neznamych_);
   neznama_ nez;
   
-  for (ClusterList::const_iterator clptr=CL.begin(); clptr!=CL.end(); ++clptr)
+  for (ClusterList::iterator clptr=CL.begin(); clptr!=CL.end(); ++clptr)
     if (StandPoint* standpoint=dynamic_cast<StandPoint*>(*clptr))
       /*
        * in the following if (...) statement we test index of an orientation
@@ -287,37 +306,39 @@ void LocalNetwork::project_equations()
 
   reset(A, b);
 
-  //--ofstream opr("A_scaled.bin", ios::trunc); 
+  //--ofstream opr("A_scaled.bin", ios_base::trunc); 
   //--int m=A.rows();
   //--int n=A.cols();
-  //--opr.write(&m, sizeof(int));
-  //--opr.write(&n, sizeof(int));
-  //--opr.write(A.begin(), sizeof(Double)*m*n);
-  
+  //--opr.write((char*)(&m), sizeof(int));
+  //--opr.write((char*)(&n), sizeof(int));
+  //--opr.write((char*)(A.begin()), sizeof(Double)*m*n);
+
   delete[] min_x_;
   min_x_ = 0;
   min_n_ = 0;
-  {   // for ...
-    for (PointData::iterator i=PD.begin(); i!=PD.end(); ++i)
-      {
-        if ((*i).second.constrained_xy())  min_n_ += 2;
-        if ((*i).second.constrained_z())   min_n_ += 1;
-      }
-  }   // for ...
+
+  for (PointData::iterator i=PD.begin(); i!=PD.end(); ++i)
+    {
+      const LocalPoint& p = (*i).second;
+      if (p.constrained_xy() && p.index_x())  min_n_ += 2;
+      if (p.constrained_z()  && p.index_z())  min_n_ += 1;
+    }
+
   if (min_n_)
     {
       min_x_ = new Index[min_n_];
       int n = 0;
       for (PointData::iterator i=PD.begin(); i!=PD.end(); ++i)
         {
-          if ((*i).second.constrained_xy())
+          const LocalPoint& p = (*i).second;
+          if (p.constrained_xy() && p.index_x())
             {
-              min_x_[n++] = (*i).second.index_y();
-              min_x_[n++] = (*i).second.index_x();
+              min_x_[n++] = p.index_y();
+              min_x_[n++] = p.index_x();
             }
-          if ((*i).second.constrained_z())
+          if (p.constrained_z() && p.index_z())
             {
-              min_x_[n++] = (*i).second.index_z();
+              min_x_[n++] = p.index_z();
             }
         }
       min_x(min_n_, min_x_);
@@ -710,7 +731,7 @@ void LocalNetwork::prepareProjectEquations()
 
   for (ClusterList::const_iterator 
          cluster=OD.CL.begin(); cluster!=OD.CL.end(); ++cluster)
-    if (const Index N = (*cluster)->activeCount())
+    if (const Index N = (*cluster)->activeObs())
         {
           Vec t(N);
           Cov C = (*cluster)->activeCov();
@@ -813,7 +834,7 @@ void LocalNetwork::vyrovnani_()
     
     for (ClusterList::const_iterator 
            cluster=OD.CL.begin(); cluster!=OD.CL.end(); ++cluster)
-      if (const Index N = (*cluster)->activeCount())
+      if (const Index N = (*cluster)->activeObs())
         {
           Vec t(N), u(N);
           Cov C = (*cluster)->activeCov();
@@ -852,12 +873,12 @@ void LocalNetwork::vyrovnani_()
 
     for (ClusterList::const_iterator 
            cit=OD.CL.begin(); cit!=OD.CL.end(); ++cit)
-      if (const Index N = (*cit)->activeCount())
+      if (const Index N = (*cit)->activeObs())
         {
           const Cluster& cluster = *(*cit);
           // ??? if (cluster.covariance_matrix.bandWidth())
           // ???   {
-          // ???     // vypocet pro koleralovana mereni zatim chybi !!!
+          // ???     // vypocet pro korelovana mereni zatim chybi !!!
           // ???   }
           // ??? else
             {
