@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: outlying_abs_terms.h,v 1.2 2002/05/24 19:30:51 cepek Exp $
+ *  $Id: outlying_abs_terms.h,v 1.4 2003/06/14 15:00:22 cepek Exp $
  */
 
 #ifndef GaMa_GaMaProg_Vybocujici_Absolutni_Cleny_h_
@@ -77,7 +77,7 @@ void OutlyingAbsoluteTerms(GaMaLib::LocalNetwork* IS, OutStream& out)
           PointID cc = pm->to();
           out.width(IS->maxw_id());
           out << cc.c_str();
-          out.setf(ios::fixed, ios::floatfield);
+          out.setf(ios_base::fixed, ios_base::floatfield);
           
           {   // ************************************************
             if (Distance* d = dynamic_cast<Distance*>(pm))
@@ -98,7 +98,7 @@ void OutlyingAbsoluteTerms(GaMaLib::LocalNetwork* IS, OutStream& out)
               }
             else if (Angle* u = dynamic_cast<Angle*>(pm))
               {
-                out << endl;
+                out << '\n';
                 out.width(IS->maxw_obs() + 2 + 2*(IS->maxw_id()));
                 out << (u->fs()).c_str();
                 out << T_GaMa_angle;
@@ -138,13 +138,13 @@ void OutlyingAbsoluteTerms(GaMaLib::LocalNetwork* IS, OutStream& out)
 
                 throw GaMaLib::Exception(
                    "GaMa internal error - unknown observation\n"
-                   "$Id: outlying_abs_terms.h,v 1.2 2002/05/24 19:30:51 cepek Exp $");
+                   "$Id: outlying_abs_terms.h,v 1.4 2003/06/14 15:00:22 cepek Exp $");
               }
           }   // ************************************************
           
-          out << setiosflags(ios::scientific) << setprecision(5);
+          out << setiosflags(ios_base::scientific) << setprecision(5);
           out << setw(13) << IS->rhs(i);       // 1.1.56 << pm->rhs();
-          out << endl;
+          out << '\n';
           out.flush();
         }
     }
