@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: observation.h,v 1.7 2002/09/29 14:00:19 cepek Exp $
+ *  $Id: observation.h,v 1.13 2004/02/02 17:07:49 cepek Exp $
  */
 
 #ifndef GaMaLib_Bod_Mer_Mereni_H
@@ -42,26 +42,32 @@
 #include <iostream>
 #include <vector>
 
+#include <gnu_gama/obsdata.h>
+#include <gamalib/matvec.h>
+
 namespace GaMaLib {
 
-  class Cluster;
   class PointData;
   class Observation;
 
 
-  typedef std::vector<Observation*> ObservationList ;
+  typedef GNU_gama::List<Observation*> ObservationList ;
   
   class Observation 
     {
     protected:
     
-      Cluster* cluster;
+      GNU_gama::Cluster<Observation>* cluster;
       int      cluster_index;
-      friend   class Cluster;
+      friend   class GNU_gama::Cluster<Observation>;
+      bool     check_std_dev() const;
     
     public:
+
+      typedef GaMaLib::Cov CovarianceMatrix;
     
-      Observation(const PointID& s, const PointID& c, Double m) :
+      Observation(const PointID& s, const PointID& c, Double m) 
+        :
         cluster(0), from_(s), to_(c), value_(m), active_(true),
         from_dh_(0), to_dh_(0)
         {
@@ -71,9 +77,18 @@ namespace GaMaLib {
 
       virtual Observation* clone() const = 0; 
 
-      const Cluster* ptr_cluster() const     { return cluster; }
-      Cluster*       ptr_cluster()           { return cluster; }
-      void           set_cluster(Cluster* c) { cluster = c; }
+      const GNU_gama::Cluster<Observation>* ptr_cluster() const     
+        { 
+          return cluster; 
+        }
+      GNU_gama::Cluster<Observation>* ptr_cluster()           
+        { 
+          return cluster; 
+        }
+      void set_cluster(GNU_gama::Cluster<Observation>* c) 
+        { 
+          cluster = c; 
+        }
 
       const PointID& from() const { return from_;    }
       const PointID& to()   const { return to_;      }
@@ -103,30 +118,7 @@ namespace GaMaLib {
       void    set_from_dh(Double h) { from_dh_ = h; }
       void    set_to_dh  (Double h) { to_dh_   = h; }
 
-      // function objects to be used with ObservationData::for_each()
-
-      class CopyTo {
-        ObservationList& OL;
-      public:
-        CopyTo(ObservationList& ol) : OL(ol) {}
-        void operator()(Observation* obs) { OL.push_back(obs); }
-      };
-      
-      class CopyActiveTo {
-        ObservationList& OL;
-      public:
-        CopyActiveTo(ObservationList& ol) : OL(ol) {}
-        void operator()(Observation* obs) { 
-          if(obs->active()) OL.push_back(obs); 
-        }
-      }; 
-
-      class CopyHorizontalTo {    // directions, angles, distances
-        ObservationList& OL;
-      public:
-        CopyHorizontalTo(ObservationList& ol) : OL(ol) {}
-        void operator()(Observation* obs);
-      }; 
+      int     dimension() const { return 1; }
 
     private:
     
