@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: gkfparser.cpp,v 1.6 2002/10/18 20:52:29 cepek Exp $
+ *  $Id: gkfparser.cpp,v 1.10 2003/05/11 12:32:25 cepek Exp $
  */
 
 
@@ -30,10 +30,10 @@
 #include <cmath>
 
 #include <gamalib/xml/gkfparser.h>
-#include <gamalib/xml/encoding.h>
+#include <gnu_gama/xml/encoding.h>
 #include <gamalib/observation.h>
 #include <gamalib/cluster.h>
-#include <gamalib/intfloat.h>
+#include <gnu_gama/intfloat.h>
 #include <gamalib/language.h>
 
 
@@ -429,8 +429,8 @@ namespace GaMaLib {
           }
         else if (nam == "angles")
           {
-            if      (val == "right-handed") OD.right_handed_angles = true;
-            else if (val == "left-handed" ) OD.right_handed_angles = false;
+            if      (val == "right-handed") SB.right_handed_angles = true;
+            else if (val == "left-handed" ) SB.right_handed_angles = false;
             else
               return error(T_GKF_undefined_value_of_attribute
                            + nam + " = " + val);            
@@ -1478,7 +1478,7 @@ namespace GaMaLib {
 #ifdef GaMaLib_GKFparser_demo
 
 #include <fstream>
-#include <gamalib/version.h>
+#include <gnu_gama/version.h>
 #include <gamalib/local/pobs/format.h>
 
 using namespace GaMaLib;
