@@ -20,19 +20,34 @@
 */
 
 /*
- *  $Id: gkfparser.h,v 1.6 2002/12/18 08:00:14 cepek Exp $
+ *  $Id: gkfparser.h,v 1.10 2003/05/11 12:32:25 cepek Exp $
  */
 
 #ifndef GaMaLib_GKF__XML__parser__h_
 #define GaMaLib_GKF__XML__parser__h_
 
-#include <gamalib/xml/baseparser.h>
+#include <gnu_gama/xml/baseparser.h>
 #include <gamalib/local/gamadata.h>
 
 
 namespace GaMaLib {
 
-  class GKFparser : public BaseParser 
+
+  class ParserException : public GaMaLib::Exception 
+  {
+  public:
+
+    int line, error_code;
+
+    ParserException(std::string s, int r, int c)
+      : GaMaLib::Exception(s), line(r), error_code(c) 
+      {
+      }
+
+  };
+
+
+  class GKFparser : public GNU_gama::BaseParser<ParserException>
     {
     public:
    
