@@ -20,16 +20,24 @@
  * available.  Attribute EN is ignored on input and serves as a kind
  * of comment.
  * 
- * $Id: slovnikar.cpp,v 1.4 2002/11/22 17:46:22 cepek Exp $
+ * $Id: slovnikar.cpp,v 1.8 2003/08/14 16:20:26 cepek Exp $
  *
  * ------------------------------------------------------------------------ */
 
          const int    N = 4;
          const char* language[N] = { "en", "cz", "fi", "du" };
 
-         const char* version = "1.01";
+         const char* version = "1.03";
 
 /* ---------------------------------------------------------------------------
+ *
+ * 1.03  2003-05-09
+ *
+ *       - encoding.[h|cpp] moved to gnu_gama/xml (from gamalib)
+ *
+ * 1.02  2003-03-16
+ *
+ *       - processing moved from build-dictionaries to Makefile-slovnikar 
  *
  * 1.01  2002-11-22
  *
@@ -104,10 +112,10 @@ Dictionary dict;
 
 // ---------------------------------------------------------------------------
 
-#include <expat/xmlparse/xmlparse.h>
-#include <gamalib/xml/encoding.h>
+#include <gnu_gama/xml_expat.h>
+#include <gnu_gama/xml/encoding.h>
 
-using namespace GaMaLib;
+using namespace GNU_gama;
 
 enum parser_state { START, ENTRIES, ENTRY, END };
 int  result = 0;
@@ -239,6 +247,7 @@ Parser::Parser(string fn)
   state = START;
   
   ifstream inp(filename.c_str());
+  if (!inp) cerr << "cannot open file " << filename << endl;
   char   c;
   while (getline(inp, text))
     {
